Description Usage Arguments Value Functions
Scale colors or fill for ggplot aesthetics
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 |
palette |
name of the palette to be used. See |
discrete |
logical determining if a discreate (finite values) scale should be created or a continuous interpolation between colors of given palette |
reversed |
shoudl hte order of the colors be reversed |
n_colors |
selection of colors to be in the palette.
See |
... |
other parameter passed to |
ggplot2::discrete_scale or scale_color_gradientn with selected colors
scale_fill_nudz: Scale fill
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.