Description Usage Arguments Value
Creates palette to be used in scales or elsewhere
1 2 3 4 5 6 7 |
palette |
name of the palette to interpolate.
|
reversed |
logical determining if the order of the colors should be reversed |
n_colors |
either how many colors from the palette to interpolate or indices of colors which to interpolate from the palette. If a single number (n) then colors 1...n will be selected. If multiple numbers are passed then the colors at given indices are selected. if empty, all colors are used in defining the palette. Defaults to empty. |
discrete |
should the palette be only discrete values |
... |
optional parameters passed to colorRampPalette if discrete is set to FALSE |
vector of hex colors if discrete is TRUE and colorRamp object if FALSE. Prepares the color interpolation object to be used in construction of your own
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.